@@ -7,26 +7,13 @@ use base 'Geo::Coder::Many::Generic';
 
 =head1 NAME
 
-Geo::Coder::Many::Bing - Plugin for the Bing geocoder
-
-=head1 VERSION
-
-Version 0.02
-
-=cut
-
-our $VERSION = '0.02';
-
-# Requires Geo::Coder::Bing 0.10 or above
-sub _MIN_MODULE_VERSION { return '0.10'; }
+Geo::Coder::Many::Bing
 
 =head1 SYNOPSIS
 
 This class wraps Geo::Coder::Bing such that it can be used in
 Geo::Coder::Many, by converting the results to a standard form.
 
-Requires Geo::Coder::Bing >= 0.10
-
 =head1 METHODS
 
 =head2 geocode
@@ -53,21 +40,23 @@ sub geocode {
         'Unknown' => undef,
     );
 
-    foreach my $raw_reply (@raw_replies) {
+    for my $raw_reply (@raw_replies) {
 
         my $tmp = {
             address     => $raw_reply->{address}->{formattedAddress},
             country     => $raw_reply->{address}->{countryRegion},
-            latitude    => $raw_reply->{point}->{coordinates}->[0],
-            longitude   => $raw_reply->{point}->{coordinates}->[1],
+            longitude   => $raw_reply->{point}->{coordinates}->[0],
+            latitude    => $raw_reply->{point}->{coordinates}->[1],
             precision   => $convert{$raw_reply->{confidence}},
         };
+
         $Response->add_response( $tmp, $self->get_name());
     }
 
     $Response->set_response_code($http_response->code());
-    return $Response;
-}
+
+    return( $Response );
+};
 
 =head2 get_name
 
@@ -75,7 +64,8 @@ The short name by which Geo::Coder::Many can refer to this geocoder.
 
 =cut
 
-sub get_name { my $self = shift; return 'bing ' . $self->{GeoCoder}->VERSION; }
+sub get_name { return 'bing' };
+
 
 1;
 
