@@ -3,18 +3,10 @@ package Geo::Coder::Many::Response;
 use strict;
 use warnings;
 
-our $VERSION = '0.01';
-
 =head1 NAME
 
-Geo::Coder::Many::Response - standard geocoder response container object
-
 =head1 DESCRIPTION
 
-This module provides a standard response format for geocoder results - the
-various geocoder plugins should all do the necessary conversions to return a
-response in this format.
-
 =head1 METHODS
 
 =head2 new
@@ -36,13 +28,12 @@ sub new {
 
     bless $self, $class;
 
-    return $self;
-}
+    return( $self );
+};
 
 =head2 add_response
 
-Takes a response, together with the name of the geocoder used to produce it,
-and stores it.
+Takes a response, together with the name of the geocoder used to produce it, and stores it.
 
 =cut
 
@@ -53,13 +44,14 @@ sub add_response {
 
     $self->{geocoder} = $geocoder;
 
-    if ( $response->{longitude} && $response->{latitude} ) {
+    if( $response->{longitude} && $response->{latitude} ) {
         push @{$self->{responses}}, $response;
         $self->{response_code} = 200;
-	return 1;
     }
-    return 0;
-}
+    else { return( 0 ) };
+
+    return( 1 );
+};
 
 =head2 set_response_code
 
@@ -69,6 +61,7 @@ sub set_response_code {
     my $self = shift;
     my $response_code = shift;
     $self->{response_code} = $response_code;
+
     return $response_code;
 }
 
@@ -78,7 +71,8 @@ Getter for the location string
 
 =cut
 
-sub get_location { return shift->{location}; }
+sub get_location { return( shift->{location} ) };
+
 
 =head2 get_response_code
 
@@ -86,7 +80,8 @@ Getter for the response code
 
 =cut
 
-sub get_response_code { return shift->{response_code}; }
+sub get_response_code { return( shift->{response_code} ) };
+
 
 =head2 get_geocoder
 
@@ -94,7 +89,7 @@ Getter for the geocoder name
 
 =cut
 
-sub get_geocoder { return shift->{geocoder}; }
+sub get_geocoder { return( shift->{geocoder} ) };
 
 =head2 get_responses
 
@@ -105,7 +100,9 @@ first response.
 
 sub get_responses {
     my $self = shift;
+
     return wantarray ? @{$self->{responses}} : $self->{responses}->[0];
-}
+};
+
 
 1;
