@@ -5,11 +5,9 @@ use warnings;
 
 use base 'Geo::Coder::Many::Scheduler';
 
-our $VERSION = '0.01';
-
 =head1 NAME
 
-Geo::Coder::Many::Scheduler::OrderedList - Ordered list scheduler
+Geo::Coder::Many::Scheduler::OrderedList
 
 =head1 DESCRIPTION
 
@@ -27,16 +25,14 @@ sub new {
     my $class = shift;
     my $ra_items = shift;
 
-    my @names =
-        map { $_->{name} } 
-        sort { $b->{weight} <=> $a->{weight}; } @$ra_items;
+    my @names = map { $_->{name} } sort { $b->{weight} <=> $a->{weight}; } @$ra_items;
 
     my $self = { items => \@names };
     bless $self, $class;
 
     $self->reset_available();
 
-    return $self;
+    return ( $self );
 }
 
 =head2 reset_available
@@ -59,7 +55,7 @@ Returns the next item in the list.
 
 sub get_next_unique {
     my $self = shift;
-    return shift @{$self->{ available_items }};
+    return ( shift @{$self->{ available_items }} );
 }
 
 =head2 next_available 
@@ -71,11 +67,7 @@ Returns zero if there are items available, and
 
 sub next_available {
     my $self = shift;
-
-    if ( 0 < @{$self->{ available_items }} ) {
-        return 0;
-    }
-    return 1;
+    return ( 0 < @{$self->{ available_items }} ? 0 : -1 );
 }
 
 1;
