@@ -7,12 +7,9 @@ use List::MoreUtils qw( first_index );
 
 use base 'Geo::Coder::Many::Scheduler';
 
-our $VERSION = '0.01';
-
 =head1 NAME
 
-Geo::Coder::Many::Scheduler::UniquenessScheduler - Scheduler base class which
-ensures uniqueness
+Geo::Coder::Many::Scheduler::UniquenessScheduler
 
 =head1 DESCRIPTION
 
@@ -26,8 +23,8 @@ Subclasses should
 
 =head2 new
 
-Creates a UniquenessScheduler object and returns it. This should not be called
-directly, but by any subclasses, via SUPER.
+Creates a UniquenessScheduler object and returns it. This should not be called directly,
+but by any subclasses, via SUPER.
 
 =cut
 
@@ -43,13 +40,12 @@ sub new {
 
     # Initialize available_items
     $self->reset_available();
-    return $self;
+    return ($self);
 };
 
 =head2 reset_available
 
-Update the set of currently available items to the full set of items initially
-provided.
+Update the set of currently available items to the full set of items initially provided.
 
 =cut
 
@@ -89,8 +85,7 @@ sub get_next_unique {
         return;
     }
     
-    # Remember that we've seen this item, by removing it from the list of those
-    # available
+    # Remember that we've seen this item, by removing it from the list of those available
     if ( $item_pos > -1 ) {
         splice @{$self->{available_items}},$item_pos,1;
     }
@@ -107,8 +102,7 @@ sub next_available {
     my $self = shift;
     if ( 0 == @{$self->{available_items}} ) {
         return;
-    }
-    else {
+    } else {
         return 0;
     }
 }
@@ -121,7 +115,7 @@ Shoudl be implemented by a subclass
 
 sub _get_next {
     die "This method must be over-ridden.\n";
-}
+};
     
 =head2 process_feedback
 
@@ -131,7 +125,7 @@ Does nothing by default; may be overridden
 
 sub process_feedback {
     return;
-}
+};
 
 1;
 
