@@ -7,12 +7,9 @@ use Carp;
 
 use base 'Geo::Coder::Many::Scheduler::UniquenessScheduler';
 
-our $VERSION = '0.01';
-
 =head1 NAME
 
-Geo::Coder::Many::Scheduler::UniquenessScheduler::WRR - Weighted Round Robin
-scheduler (default)
+Geo::Coder::Many::Scheduler::UniquenessScheduler::WRR
 
 =head1 DESCRIPTION
 
@@ -38,15 +35,14 @@ sub new {
     
     my $WeightedList = List::Util::WeightedRoundRobin->new();
     my $self =  $class->SUPER::new({items => $ra_geocoders});
-    $self->{weighted_list} 
-        = $WeightedList->create_weighted_list( $ra_geocoders );
+    $self->{weighted_list} = $WeightedList->create_weighted_list( $ra_geocoders );
 
     unless( @{$self->{weighted_list}} ) {
         carp "Unable to create weighted list from list of geocoders";
     };
 
     bless $self, $class;
-    return $self;
+    return ($self);
 }
 
 =head1 INTERNAL METHODS
