@@ -5,11 +5,9 @@ use warnings;
 
 use base 'Geo::Coder::Many::Scheduler::UniquenessScheduler';
 
-our $VERSION = '0.01';
-
 =head1 NAME
 
-Geo::Coder::Many::Scheduler::WeightedRandom - Weighted random scheduler
+Geo::Coder::Many::Scheduler::WeightedRandom
 
 =head1 DESCRIPTION
 
@@ -29,15 +27,12 @@ sub new {
     my $class = shift;
     my $ra_geocoders = shift;
 
-    # Convert weights (= desired frequencies) into a cumulative distribution
-    # function
+    # Convert weights (= desired frequencies) into a cumulative distribution function
     my $total_weight = 0;
     for my $rh_geo (@$ra_geocoders) {
         my $weight = $rh_geo->{weight};
         if ($weight <= 0) {
-            warn "Warning - weight for "
-                 .$rh_geo->{geocoder}
-                 ." should be greater than zero"; 
+            warn "Warning - weight for ". $rh_geo->{geocoder} ." should be greater than zero.\n"; 
         }
         $rh_geo->{weight} = $weight + $total_weight;
         $total_weight += $weight;
